SphereQLQuery

Enum SphereQLQuery 

pub enum SphereQLQuery<'a> {
    Nearest {
        k: usize,
    },
    SimilarAbove {
        min_cosine: f64,
    },
    ConceptPath {
        source_id: &'a str,
        target_id: &'a str,
        graph_k: usize,
    },
    DetectGlobs {
        k: Option<usize>,
        max_k: usize,
    },
    LocalManifold {
        neighborhood_k: usize,
    },
    CategoryConceptPath {
        source_category: &'a str,
        target_category: &'a str,
    },
    CategoryNeighbors {
        category: &'a str,
        k: usize,
    },
    DrillDown {
        category: &'a str,
        k: usize,
    },
    CategoryStats,
}
Typed query request.

Variants



Nearest

Find the k nearest neighbors to the query embedding.

Fields



SimilarAbove

Find all neighbors within a cosine similarity threshold.

Fields

min_cosine: f64


ConceptPath

Find the shortest concept path between two indexed items.

Fields

source_id: &'a str
target_id: &'a str
graph_k: usize


DetectGlobs

Detect concept globs. k=None for auto-detection.

Fields

max_k: usize


LocalManifold

Fit a local manifold around the query point.

Fields

neighborhood_k: usize


CategoryConceptPath

Find the shortest path between two categories through the category graph.

Fields

source_category: &'a str
target_category: &'a str


CategoryNeighbors

Find the k nearest neighbor categories to the given category.

Fields

category: &'a str


DrillDown

Drill down into a category: k-NN within the category, using the inner sphere’s projection if available.

Fields

category: &'a str


CategoryStats

Get summary statistics for all categories and inner spheres.