pub struct SelfTuneReport {
pub iterations: Vec<SelfTuneIteration>,
pub stopped_reason: StopReason,
pub final_composite: Option<f64>,
}Expand description
Full run report.
Fields
iterations: Vec<SelfTuneIteration>stopped_reason: StopReasonfinal_composite: Option<f64>Composite score of the corpus as returned to the caller — i.e.
after the final iteration’s reweight and prune. The
per-iteration composite_scores are entry scores, so this is
the only measurement of the state that actually gets persisted.
None when the final corpus is too small to build a pipeline.