Module types

Module types 

Structs

Embedding
A high-dimensional embedding vector.
ProjectedPoint
A projected point on the sphere with rich attributes from the projection.
RadialContext
Per-point information available when resolving the radial coordinate.

Enums

RadialStrategy
Controls how the radial coordinate r is computed from an embedding.