Module types
sphereql_
embed
0.1.0-alpha
Module types
Module Items
Structs
Enums
In crate sphereql_
embed
sphereql_embed
Module
types
Structs

Embedding
Projected
Point
A projected point on the sphere with rich attributes from the projection.
Enums

Radial
Strategy
Controls how the radial coordinate r is computed from an embedding.